@@ -404,9 +404,9 @@ def saslprep(source, param="value"):
     for c in data:
         # check for chars mapping stage should have removed
         assert not stringprep.in_table_b1(c), "failed to strip B.1 in mapping stage"
-        assert not stringprep.in_table_c12(
-            c
-        ), "failed to replace C.1.2 in mapping stage"
+        assert not stringprep.in_table_c12(c), (
+            "failed to replace C.1.2 in mapping stage"
+        )
 
         for func, err_msg in forbidden_:
             if func(c):
@@ -580,7 +580,7 @@ def is_ascii_safe(source: AnyStr) -> bool:
 
 
 def to_bytes(
-    source: AnyStr,
+    source: str | bytes,
     encoding: str = "utf-8",
     param: str = "value",
     source_encoding: str | None = None,
@@ -668,8 +668,8 @@ def to_hash_str(source, encoding="ascii"):  # pragma: no cover -- deprecated & u
     return to_native_str(source, encoding, param="hash")
 
 
-_true_set = set("true t yes y on 1 enable enabled".split())
-_false_set = set("false f no n off 0 disable disabled".split())
+_true_set = set(["true", "t", "yes", "y", "on", "1", "enable", "enabled"])
+_false_set = set(["false", "f", "no", "n", "off", "0", "disable", "disabled"])
 _none_set = set(["", "none"])
 
 
